@@ -30,6 +30,8 @@ gsnodegraph_nodedisconnect_cmd_event, EVT_GSNODEGRAPH_NODEDISCONNECT = NewComman
 gsnodegraph_mousezoom_cmd_event, EVT_GSNODEGRAPH_MOUSEZOOM = NewCommandEvent()
 
 ID_CONTEXTMENU_DELETENODE = wx.NewIdRef()
+ID_CONTEXTMENU_MUTENODE = wx.NewIdRef()
+ID_CONTEXTMENU_UNMUTENODE = wx.NewIdRef()
 ID_CONTEXTMENU_DELETENODES = wx.NewIdRef()
 ID_CONTEXTMENU_DUPLICATENODE = wx.NewIdRef()
 ID_CONTEXTMENU_DESELECTALLNODES = wx.NewIdRef()
@@ -83,6 +85,10 @@ class NodeGraph(wx.ScrolledCanvas):
         self.Bind(wx.EVT_CONTEXT_MENU, self.OnContextMenu)
         self.Bind(wx.EVT_MENU, self.OnDeleteNode,
                           id=ID_CONTEXTMENU_DELETENODE)
+        self.Bind(wx.EVT_MENU, self.OnMuteNode,
+                          id=ID_CONTEXTMENU_MUTENODE)
+        self.Bind(wx.EVT_MENU, self.OnUnmuteNode,
+                          id=ID_CONTEXTMENU_UNMUTENODE)
         self.Bind(wx.EVT_MENU, self.OnDeleteNodes,
                           id=ID_CONTEXTMENU_DELETENODES)
         self.Bind(wx.EVT_MENU, self.OnSelectAllNodes,
@@ -92,6 +98,16 @@ class NodeGraph(wx.ScrolledCanvas):
         self.Bind(wx.EVT_MENU, self.OnDuplicateNode,
                           id=ID_CONTEXTMENU_DUPLICATENODE)
 
+        # Keyboard shortcut bindings
+        self.accel_tbl = wx.AcceleratorTable([(wx.ACCEL_SHIFT, ord('D'),
+                                               ID_CONTEXTMENU_DUPLICATENODE),
+                                              (wx.ACCEL_SHIFT, ord('M'),
+                                               ID_CONTEXTMENU_MUTENODE),
+                                              (wx.ACCEL_NORMAL, wx.WXK_DELETE,
+                                               ID_CONTEXTMENU_DELETENODES),
+                                              ])
+        self.parent.SetAcceleratorTable(self.accel_tbl)
+
 
     def OnPaint(self, event):
         dc = wx.BufferedPaintDC(self, self._buffer)
@@ -294,6 +310,14 @@ class NodeGraph(wx.ScrolledCanvas):
 
         self.UpdateDrawing()
 
+    def OnMuteNode(self, event):
+        self._active_node.SetMuted(True)
+        self.UpdateDrawing()
+
+    def OnUnmuteNode(self, event):
+        self._active_node.SetMuted(False)
+        self.UpdateDrawing()
+
     def OnSelectAllNodes(self, event):
         """ Event that selects all the nodes in the Node Graph. """
         for node_id in self._nodes:
@@ -334,28 +358,46 @@ class NodeGraph(wx.ScrolledCanvas):
             if self._active_node.IsOutputNode() != True:
                 duplicate_menuitem = flatmenu.FlatMenuItem(self.context_menu,
                                                            ID_CONTEXTMENU_DUPLICATENODE,
-                                                           "Duplicate\tShift+D", "", wx.ITEM_NORMAL)
+                                                           "{0}{1}".format(_("Duplicate"), "\tShift+D"), "",
+                                                           wx.ITEM_NORMAL)
                 self.context_menu.AppendItem(duplicate_menuitem)
                 delete_menuitem = flatmenu.FlatMenuItem(self.context_menu,
                                                         ID_CONTEXTMENU_DELETENODE,
-                                                        "Delete\tDel", "", wx.ITEM_NORMAL)
+                                                        "{0}{1}".format(_("Delete"), "\tDel"), "",
+                                                        wx.ITEM_NORMAL)
                 self.context_menu.AppendItem(delete_menuitem)
 
+                if self._active_node.IsMuted() is not True:
+                    mute_menuitem = flatmenu.FlatMenuItem(self.context_menu,
+                                                            ID_CONTEXTMENU_MUTENODE,
+                                                            "{0}{1}".format(_("Mute"), "\tShift+M"), "",
+                                                            wx.ITEM_NORMAL)
+                    self.context_menu.AppendItem(mute_menuitem)
+                else:
+                    unmute_menuitem = flatmenu.FlatMenuItem(self.context_menu,
+                                                            ID_CONTEXTMENU_UNMUTENODE,
+                                                            _("Unmute"), "",
+                                                            wx.ITEM_NORMAL)
+                    self.context_menu.AppendItem(unmute_menuitem)
+
         else:
             if self._selected_nodes != []:
                 deletenodes_menuitem = flatmenu.FlatMenuItem(self.context_menu,
                                                              ID_CONTEXTMENU_DELETENODES,
-                                                             "Delete Selected\tDel", "", wx.ITEM_NORMAL)
+                                                             "{0}{1}".format(_("Delete Selected"), "\tDel"), "",
+                                                             wx.ITEM_NORMAL)
                 self.context_menu.AppendItem(deletenodes_menuitem)
 
         selectallnodes_menuitem = flatmenu.FlatMenuItem(self.context_menu,
                                                         ID_CONTEXTMENU_SELECTALLNODES,
-                                                        "Select All", "", wx.ITEM_NORMAL)
+                                                        "Select All", "",
+                                                        wx.ITEM_NORMAL)
         self.context_menu.AppendItem(selectallnodes_menuitem)
 
         deselectallnodes_menuitem = flatmenu.FlatMenuItem(self.context_menu,
                                                           ID_CONTEXTMENU_DESELECTALLNODES,
-                                                          "Deselect All", "", wx.ITEM_NORMAL)
+                                                          "Deselect All", "",
+                                                          wx.ITEM_NORMAL)
         self.context_menu.AppendItem(deselectallnodes_menuitem)
 
 
@@ -464,12 +506,12 @@ class NodeGraph(wx.ScrolledCanvas):
         if self._tmp_wire != None:
             self._tmp_wire.Draw(dc)
 
-        if self._bbox_start != None and self._bbox_rect != None:
-            self.DrawSelectionBox(dc, self._bbox_rect)
-
         for wire in self._wires:
             wire.Draw(dc)
 
+        if self._bbox_start != None and self._bbox_rect != None:
+            self.DrawSelectionBox(dc, self._bbox_rect)
+
     def OnDrawInterface(self, dc):
         pass
 
